Stan Math Library: stan/math/prim/mat/meta/index_type.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
index_type.hpp File Reference
`#include <stan/math/prim/scal/meta/index_type.hpp>`
`#include <Eigen/Core>`

Go to the source code of this file.

## Classes
struct | stan::math::index_type< Eigen::Matrix< T, R, C > >
| Template metaprogram defining typedef for the type of index for an Eigen matrix, vector, or row vector. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.